package cn.com.ctop.crawler.modules.core.util;

import cn.com.ctop.crawler.modules.appium.entity.AppiumTaskItem;
import com.google.gson.Gson;
import io.appium.java_client.TouchAction;
import io.appium.java_client.android.AndroidDriver;
import io.appium.java_client.touch.WaitOptions;
import io.appium.java_client.touch.offset.PointOption;
import lombok.extern.slf4j.Slf4j;
import org.openqa.selenium.Point;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.remote.DesiredCapabilities;

import java.net.URL;
import java.time.Duration;
import java.util.List;

@Slf4j
public class AppiumUtil {
    private Boolean isLoop = true;
    private Duration duration = Duration.ofSeconds(1);

    public static final String FIND_ELEMENT_TYPE_ID = "id";
    public static final String FIND_ELEMENT_TYPE_XPATH = "xpath";
    public static final String FIND_ELEMENT_TYPE_CLASS = "class";
    public static final String APP_SWIPE_TYPE_UP = "up";
    public static final String APP_SWIPE_TYPE_DOWN = "down";
    public static final String APP_SWIPE_TYPE_LEFT = "left";
    public static final String APP_SWIPE_TYPE_RIGHT = "right";

    public void swipeToUp(AndroidDriver driver) {
        int width = driver.manage().window().getSize().width;
        int height = driver.manage().window().getSize().height;
        TouchAction action1 = new TouchAction(driver).press(PointOption.point(width / 2, height * 3 / 4)).waitAction(WaitOptions.waitOptions(duration))
                .moveTo(PointOption.point(width / 2, height / 4)).release();
        action1.perform();
    }

    public void swipeToDown(AndroidDriver driver) {
        int width = driver.manage().window().getSize().width;
        int height = driver.manage().window().getSize().height;
        TouchAction action2 = new TouchAction(driver).press(PointOption.point(width / 2, height / 4)).waitAction(WaitOptions.waitOptions(duration))
                .moveTo(PointOption.point(width / 2, height * 3 / 4)).release();
        action2.perform();
    }

    public void swipeToLeft(AndroidDriver driver) {
        int width = driver.manage().window().getSize().width;
        int height = driver.manage().window().getSize().height;
        TouchAction action3 = new TouchAction(driver).press(PointOption.point(width * 3 / 4, height / 2)).waitAction(WaitOptions.waitOptions(duration))
                .moveTo(PointOption.point(width / 4, height / 2)).release();
        action3.perform();
    }

    public void tapPoint(AndroidDriver driver, Integer x, Integer y) {
        TouchAction action = new TouchAction(driver).tap(PointOption.point(x, y)).release();
        action.perform();
    }

    public void swipeToRight(AndroidDriver driver) {
        int width = driver.manage().window().getSize().width;
        int height = driver.manage().window().getSize().height;
        TouchAction action4 = new TouchAction(driver).press(PointOption.point(width / 4, height / 2)).waitAction(WaitOptions.waitOptions(duration))
                .moveTo(PointOption.point(width * 3 / 4, height / 2)).release();
        action4.perform();
    }

    public AndroidDriver initAndroidDriver(String serverUrl, String deviceName, String appPackage, String appActivity) throws Exception {
        return new AndroidDriver(new URL(serverUrl), initCapabilities(deviceName, appPackage, appActivity));
    }

    public DesiredCapabilities initCapabilities(String deviceName, String appPackage, String appActivity) {
        DesiredCapabilities desiredCapabilities = new DesiredCapabilities();
        desiredCapabilities.setCapability("deviceName", deviceName);
        desiredCapabilities.setCapability("platformName", "Android");
        desiredCapabilities.setCapability("appPackage", appPackage);
        desiredCapabilities.setCapability("noReset", true);
        desiredCapabilities.setCapability("unicodeKeyboard", true);
        desiredCapabilities.setCapability("resetKeyboard", true);
        desiredCapabilities.setCapability("appActivity", appActivity);
        return desiredCapabilities;
    }

    public static void main(String[] args) {
        AppiumUtil appiumUtil = new AppiumUtil();
        try {
//            AndroidDriver androidDriver = appiumUtil.initAndroidDriver("http://39.106.184.70:4723/wd/hub", "183.131.157.66:10005", "com.smile.gifmaker", "com.yxcorp.login.userlogin.QuickLoginActivity");
            AndroidDriver androidDriver = appiumUtil.initAndroidDriver("http://39.106.184.70:4723/wd/hub", "183.131.157.66:10005", "com.smile.gifmaker", "com.yxcorp.gifshow.HomeActivity");
//            appiumUtil.loginKuaishou(androidDriver);
            appiumUtil.loginTask(androidDriver, null, null);
//            appiumUtil.test(androidDriver);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public Boolean loginTask(AndroidDriver androidDriver, String settoken, String setmobile) throws Exception {
        Thread.sleep(5000);
        String token = settoken;
        String mobile = setmobile;
        String pkg = androidDriver.getCurrentPackage();
        String activity = androidDriver.currentActivity();
        System.out.println("当前包：" + pkg);
        System.out.println("当前activity：" + activity);
        Boolean isContinue = true;
        if (pkg.equals("com.android.packageinstaller")) {
            switch (activity) {
                case ".permission.ui.GrantPermissionsActivity":
                    WebElement permissionAllowBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.android.packageinstaller:id/permission_allow_button");
                    if (permissionAllowBtn != null) {
                        permissionAllowBtn.click();
                    }
                    break;
                case ".PackageInstallerActivity":
                    WebElement okBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.android.packageinstaller:id/ok_button");
                    if (okBtn != null) {
                        okBtn.click();
                    }
                    break;
                case ".InstallAppProgress":
                    WebElement centerText = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.android.packageinstaller:id/center_text");
                    WebElement doneBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.android.packageinstaller:id/done_button");

                    if (centerText != null) {
                        System.out.println(centerText.getText());
                    }
                    if (doneBtn != null) {
                        doneBtn.click();
                    }
                    break;
                default:
                    isContinue = false;
                    System.out.println("当前activity无法处理");
                    break;
            }
        } else if (pkg.equals("com.smile.gifmaker")) {
            WebElement positive = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
            if (positive != null) {
                positive.click();
            }

            switch (activity) {
                case "com.yxcorp.gifshow.webview.KwaiWebViewActivity":
//                    WebElement leftTv = getElementById(androidDriver,"com.smile.gifmaker:id/left_tv");
                    WebElement leftBtn1 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                    if (leftBtn1 != null) {
                        leftBtn1.click();
                    }
//                    if (leftTv != null){
//                        leftTv.click();
//                    }
                    break;
                case "com.yxcorp.gifshow.HomeActivity":

                    WebElement loginText = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_text");
                    WebElement leftText = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_text");
                    WebElement phoneLoginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_login_view");
                    WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                    WebElement closeBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/close_btn");
//                    WebElement qrcodeImage = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                    if(qrcodeImage != null){
//                        qrcodeImage.click();
//                        break;
//                    }
                    if (closeBtn != null) {
                        closeBtn.click();
                        break;
                    }
                    if (loginText != null) {
                        loginText.click();
                        break;
                    }
                    if (leftText != null) {
                        leftText.click();
                        break;
                    }
                    if (phoneLoginBtn != null) {
                        phoneLoginBtn.click();
                        break;
                    }
                    if (leftBtn != null) {
                        leftBtn.click();
                        Thread.sleep(5000);
                        WebElement tabAvatar = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                        if (tabAvatar != null) {
                            tabAvatar.click();
                        } else {
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 1230);
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 1230);
                            Thread.sleep(3000);
//                            WebElement qrCodeImage = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                            if(qrCodeImage != null){
//
//                            }
                            tapPoint(androidDriver, 650, 400);
                        }
                    }
                    break;
                case "com.yxcorp.gifshow.profile.activity.MyProfileActivity":
//                    WebElement qrCodeImage = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
                    WebElement loadingTitle = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/loading_title");
                    if (loadingTitle != null) {
                        System.out.println(loadingTitle.getText());
                    }
                    tapPoint(androidDriver, 650, 400);
//                    if(qrCodeImage != null){
//
//                    }
                    break;
                case "com.yxcorp.plugin.qrcode.MyQRCodeActivity":
                    WebElement kwaiId = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                    if (kwaiId != null) {
                        System.out.println(kwaiId.getText());
                        isContinue = false;
                    }
                    break;
                case "com.yxcorp.gifshow.activity.BrowseSettingsActivity":
                    //com.smile.gifmaker:id/browse_setting_new_btn 开启大屏模式  关闭大屏模式
                    //com.smile.gifmaker:id/left_btn 返回
                    break;
                case "com.yxcorp.login.userlogin.LoginActivity":
                    WebElement loginTitleTv = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_title_tv");
                    WebElement loginNameEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_name_et");
                    WebElement nextView = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/next_view");
//                    WebElement forgetPsdBtn = getElementById(androidDriver,"com.smile.gifmaker:id/forget_psd_btn");

                    if (loginTitleTv != null) {
                        System.out.println(loginTitleTv.getText());
                        if (loginTitleTv.getText().equals("输入密码")) {
                            WebElement forgetPsdBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/forget_psd_btn");
                            if (forgetPsdBtn != null) {
                                forgetPsdBtn.click();
                            }
                        }
                    }
                    if (loginNameEt != null) {
                        token = KuaimiUtil.kuaimiLogin();
                        mobile = KuaimiUtil.getMobile(token, "2307");
                        loginNameEt.sendKeys(mobile);
                        Thread.sleep(5000);
                        nextView.click();
                    }
//                    if(forgetPsdBtn != null){
//                        forgetPsdBtn.click();
//                    }
//                    if(mobile != null){
//                        KuaimiUtil.cancelRecv(token,"2307",mobile);
//                    }
                    break;
                case "com.yxcorp.login.userlogin.RetrievePasswordActivity":
                    WebElement nameEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/name_et");
                    if (nameEt != null) {
//                        token = KuaimiUtil.kuaimiLogin();
//                        mobile = KuaimiUtil.getMobile(token, "2307");
//                        nameEt.sendKeys(mobile);
                        Thread.sleep(5000);
                        WebElement verifyTv = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/verify_tv");
                        if (verifyTv != null) {
                            verifyTv.click();
                            int i = 0;
                            String msg = null;
                            while (i < 20) {
                                i++;
                                if (msg != null) {
                                    continue;
                                }
                                try {
                                    msg = KuaimiUtil.getMessage(token, "2307", mobile);
                                } catch (Exception e) {
                                    System.out.println("等待" + mobile + "短信验证码");
                                    Thread.sleep(5000);
                                }
                            }
                            if (msg != null) {
                                WebElement verifyEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/verify_et");
                                if (verifyEt != null) {
                                    verifyEt.sendKeys(msg);
                                    Thread.sleep(5000);
                                    WebElement confirmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                    if (confirmBtn != null) {
                                        confirmBtn.click();
                                    }
                                }
                            }
                        }
                    }
                    break;
                case "com.yxcorp.login.userlogin.ResetSelectedAccountPasswordActivity":
                    WebElement confirmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                    WebElement loginPsdEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_psd_et");
                    if (loginPsdEt != null) {
                        loginPsdEt.sendKeys("a123456");
                        Thread.sleep(5000);
                        if (confirmBtn != null) {
                            confirmBtn.click();
                        }
                    }
                    break;
                case "com.yxcorp.login.userlogin.MultiLoginAccountSelectActivity":
                    WebElement iconOne = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/icon_one");
                    if (iconOne != null) {
                        iconOne.click();
                    }
                    break;
                case "com.yxcorp.login.userlogin.RegisterUserInfoSettingActivity":
                    //com.smile.gifmaker:id/right_btn
                    WebElement rightBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/right_btn");
                    if (rightBtn != null) {
                        rightBtn.click();
                    }
                    break;
                case "com.yxcorp.gifshow.activity.InterestTagActivity":
                    WebElement closeIv = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/close_iv");
                    if (closeIv != null) {
                        closeIv.click();
                    }
                    break;
                case "com.yxcorp.login.userlogin.QuickLoginActivity":
                    WebElement phoneLoginView = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_login_view");
                    if (phoneLoginView != null) {
                        phoneLoginView.click();
                    }
                    break;
                case "com.yxcorp.login.userlogin.FullScreenLoginActivity":
                    WebElement phoneOneKeyLoginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_one_key_login_btn");
                    if (phoneOneKeyLoginBtn != null) {
                        phoneOneKeyLoginBtn.click();
                    }
                    break;
                case "com.yxcorp.login.userlogin.CaptchaCodeLoginActivity":
                    WebElement captchaEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_et");
                    if (captchaEt != null) {
                        int i = 0;
                        String msg = null;
                        while (i < 20) {
                            i++;
                            if (msg != null) {
                                continue;
                            }
                            try {
                                msg = KuaimiUtil.getMessage(token, "2307", mobile);
                            } catch (Exception e) {
                                System.out.println("等待" + mobile + "短信验证码");
                                Thread.sleep(5000);
                            }
                        }
                        if (msg != null) {
                            captchaEt.sendKeys(msg);
                            Thread.sleep(5000);
                            WebElement captchaFinish = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_finish");
                            if (captchaFinish != null) {
                                captchaFinish.click();
                            }
                        }
                    }
                    //com.smile.gifmaker:id/captcha_et
                    //com.smile.gifmaker:id/captcha_finish
                    //com.smile.gifmaker:id/captcha_title  	验证码已发送至+86 18349780352
                    break;
                case "com.yxcorp.login.userlogin.PhoneLoginV2Activity":
                    WebElement phoneEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_et");
                    if (phoneEt != null) {
                        token = KuaimiUtil.kuaimiLogin();
                        mobile = KuaimiUtil.getMobile(token, "2307");
                        phoneEt.sendKeys(mobile);
                        Thread.sleep(5000);
                        WebElement fetchCodeTv = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/fetch_code_tv");
                        if (fetchCodeTv != null) {
                            fetchCodeTv.click();
                            int i = 0;
                            String msg = null;
                            while (i < 20) {
                                i++;
                                if (msg != null) {
                                    continue;
                                }
                                try {
                                    msg = KuaimiUtil.getMessage(token, "2307", mobile);
                                } catch (Exception e) {
                                    System.out.println("等待" + mobile + "短信验证码");
                                    Thread.sleep(5000);
                                }
                            }
                            if (msg != null) {
                                WebElement captchaCodeEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
                                if (captchaCodeEt != null) {
                                    captchaCodeEt.sendKeys(msg);
                                    Thread.sleep(5000);
                                    WebElement cfmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                    if (cfmBtn != null) {
                                        cfmBtn.click();
                                    }
                                }
                            }
                        }
                    }
                    break;
                default:
                    isContinue = false;
                    System.out.println("当前activity无法处理");
                    break;
            }
        } else if (pkg.equals("cn.com.longene.www.myapplication")) {
            switch (activity) {
                case ".MainActivity":
                    isContinue = false;
                    System.out.println("快手已崩溃");
                    break;
                default:
                    isContinue = false;
                    System.out.println("当前activity无法处理");
                    break;
            }
        } else {
            System.out.println("当前包为非操作包：" + pkg);
        }
        if (isContinue) {
            isContinue = loginTask(androidDriver, token, mobile);
        }
        return isContinue;
    }

    public void test(AndroidDriver androidDriver) throws Exception {
        Thread.sleep(3000L);
        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
        WebElement mobileLoginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_login_view");
        if (mobileLoginBtn != null) {
            mobileLoginBtn.click();
            Thread.sleep(2000L);
        }

        WebElement loginTypeBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_one_key_login_btn");

        if (loginTypeBtn != null) {
            loginTypeBtn.click();
            Thread.sleep(5000);
        }

        WebElement mobileLogin = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_et");
        WebElement mobileInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_name_et");
        if (mobileInput == null) {
            mobileInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_et");
        }
        if (mobileInput != null) {
            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
            String token = KuaimiUtil.kuaimiLogin();
            String mobile = KuaimiUtil.getMobile(token, "2307");
            mobileInput.sendKeys(mobile);
            Thread.sleep(2000L);
            WebElement nextBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/next_view");
            if (nextBtn != null) {
                nextBtn.click();
                Thread.sleep(5000L);
            }
            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
            WebElement pintu = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/title_tv");
            if (pintu != null && pintu.getText().equals("拖动滑块")) {
                WebElement leftBtn1 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                leftBtn1.click();
                return;
            }
            WebElement loginTitle = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_title_tv");
            WebElement forgetBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/forget_psd_btn");
            WebElement captcha = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_et");
            WebElement captchaCode = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
            if (loginTitle != null && loginTitle.getText().equals("输入密码")) {
                forgetBtn.click();
                Thread.sleep(2000L);
                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                WebElement sendMsgBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/verify_tv");
                sendMsgBtn.click();
                Thread.sleep(5000L);
                int i = 0;
                String msg = null;
                while (i < 20) {
                    try {
                        msg = KuaimiUtil.getMessage(token, "2307", mobile);
                    } catch (Exception e) {
                        System.out.println("等待" + mobile + "短信验证码");
                    }
                    if (msg != null) {
                        WebElement captchrInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/verify_et");
                        captchrInput.sendKeys(msg);
                        Thread.sleep(2000);
                        WebElement confirmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                        confirmBtn.click();
                        Thread.sleep(2000);
                        WebElement resetSelect = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/avatar_layout_one");
                        if (resetSelect != null) {
                            resetSelect.click();
                            Thread.sleep(2000);
                        }
                        WebElement newPwdInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_psd_et");
                        newPwdInput.sendKeys("a123456");
                        Thread.sleep(2000);
                        WebElement confirmBtn2 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                        confirmBtn2.click();
                        Thread.sleep(3000);
                        WebElement continueBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                        if (continueBtn != null) {
                            continueBtn.click();
                        }
                        for (int j = 0; j < 3; j++) {
                            Thread.sleep(3000);
                            WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                            if (leftBtn != null) {
                                leftBtn.click();
                            }
                        }
                        Thread.sleep(3000);
                        WebElement closeBtn1 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/close_iv");
                        if (closeBtn1 != null) {
                            closeBtn1.click();
                        }
                        for (int j = 0; j < 5; j++) {
                            Thread.sleep(3000L);
                            permissionAllow(androidDriver);
                        }
                        Thread.sleep(3000);
                        WebElement continueBtn1 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                        if (continueBtn1 != null) {
                            continueBtn1.click();
                        }
                        for (int j = 0; j < 3; j++) {
                            Thread.sleep(3000L);
                            closeBtnClick(androidDriver);
                        }
                        Thread.sleep(3000);
                        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                        WebElement headImg = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                        if (headImg != null) {
                            headImg.click();
                            Thread.sleep(3000);
                            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                            tapPoint(androidDriver, 650, 400);
                            Thread.sleep(3000);
                            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
//                                    WebElement qrCode = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                            WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                            System.out.println(kwid.getText());
                        } else {
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 1230);
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 1230);
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 400);
                            Thread.sleep(3000);
//                                    WebElement qrCode = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                            WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                            System.out.println(kwid.getText());
                        }

                        break;
                    }
                    i++;
                    Thread.sleep(5000);
                }
                if (i == 20) {
                    KuaimiUtil.addBlackList(token, "2307", mobile);
                }
            } else if (captcha != null) {
                int i = 0;
                String msg = null;
                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                while (i < 20) {

                    try {
                        msg = KuaimiUtil.getMessage(token, "2307", mobile);
                    } catch (Exception e) {
                        System.out.println("等待" + mobile + "短信验证码");
                    }
                    if (msg != null) {
                        Thread.sleep(2000);
                        WebElement captchaInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_et");
                        captchaInput.sendKeys(msg);
                        Thread.sleep(10000);
                        WebElement captchaConfirm = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_finish");

                        captchaConfirm.click();
                        System.out.println(msg);
                        Thread.sleep(5000);
                        WebElement icon = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "//android.widget.ImageView[@content-desc=\"头像\"]");
                        if (icon != null) {
                            icon.click();
                        }
                        Thread.sleep(3000);
                        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                        WebElement continueBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                        if (continueBtn != null) {
                            continueBtn.click();
                        }
                        for (int j = 0; j < 3; j++) {
                            Thread.sleep(3000);
                            WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                            if (leftBtn != null) {
                                leftBtn.click();
                            }
                        }
                        Thread.sleep(3000);
                        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                        WebElement headImg = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                        if (headImg != null) {
                            headImg.click();
                            Thread.sleep(3000);
                            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                            tapPoint(androidDriver, 650, 400);
                            Thread.sleep(3000);
                            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
//                                    WebElement qrCode = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                            WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                            System.out.println(kwid.getText());
                        } else {
                            Thread.sleep(3000);
                            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                            tapPoint(androidDriver, 650, 1230);
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 1230);
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 400);
                            Thread.sleep(3000);
//                                    WebElement qrCode = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                            WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                            System.out.println(kwid.getText());
                        }
                        //封禁
                        break;
                    }
                    i++;
                    Thread.sleep(5000);
                }
                if (i == 20) {
                    KuaimiUtil.addBlackList(token, "2307", mobile);
                }
            } else if (captchaCode != null) {
                WebElement fetchCodeTv = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "fetch_code_tv");
                fetchCodeTv.click();
                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                String msg = null;
                int i = 0;
                while (i < 20) {
                    try {
                        msg = KuaimiUtil.getMessage(token, "2307", mobile);
                    } catch (Exception e) {
                        System.out.println("等待" + mobile + "短信验证码");
                    }
                    if (msg != null) {
                        WebElement captchrInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
                        captchrInput.sendKeys(msg);
                        Thread.sleep(5000);
                        WebElement confirmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                        if (confirmBtn != null) {
                            confirmBtn.click();
                        }

                        Thread.sleep(5000);
                        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                        WebElement newPwdInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_psd_et");
                        if (newPwdInput != null) {
                            newPwdInput.sendKeys("a123456");
                            Thread.sleep(5000);
                            WebElement confirmBtn2 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                            confirmBtn2.click();
                            Thread.sleep(3000);
                        }

                        WebElement continueBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                        if (continueBtn != null) {
                            continueBtn.click();
                        }
                        Thread.sleep(3000);
                        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                        for (int j = 0; i < 3; j++) {
                            Thread.sleep(3000);
                            WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                            if (leftBtn != null) {
                                leftBtn.click();
                            }
                        }

                        WebElement headImg = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                        if (headImg != null) {
                            headImg.click();
                            Thread.sleep(3000);
                            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                            WebElement qrCode = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/qr_code_image");
                            qrCode.click();
                            WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                            System.out.println(kwid.getText());
                        } else {
                            Thread.sleep(3000);
                            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                            tapPoint(androidDriver, 650, 1230);
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 1230);
                            Thread.sleep(3000);
                            tapPoint(androidDriver, 650, 400);
                            Thread.sleep(3000);
//                                    WebElement qrCode = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                            WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                            System.out.println(kwid.getText());
                        }
                        //封禁判断
                        break;
                    }
                    i++;
                    Thread.sleep(5000);
                }
                if (i == 20) {
                    KuaimiUtil.addBlackList(token, "2307", mobile);
                }

            }
        }
    }

    public void loginKuaishou(AndroidDriver androidDriver) {
        try {
            System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
            Thread.sleep(3000L);
//            Activity activity = new Activity("com.smile.gifmaker","com.yxcorp.login.userlogin.QuickLoginActivity");
//            androidDriver.startActivity(activity);
//            Thread.sleep(10000L);
            WebElement closeBtn1 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/close_iv");
            if (closeBtn1 != null) {
                closeBtn1.click();
            }
            for (int i = 0; i < 5; i++) {
                Thread.sleep(3000L);
                permissionAllow(androidDriver);
            }
            Thread.sleep(3000);
            WebElement continueBtn1 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
            if (continueBtn1 != null) {
                continueBtn1.click();
            }
            for (int i = 0; i < 3; i++) {
                Thread.sleep(3000L);
                closeBtnClick(androidDriver);
            }
            WebElement loginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_text");
            if (loginBtn != null && loginBtn.getText().equals("登录")) {
                loginBtn.click();
                Thread.sleep(3000L);
                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                WebElement mobileLoginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_login_view");
                if (mobileLoginBtn != null) {
                    mobileLoginBtn.click();
                    Thread.sleep(2000L);
                }

                WebElement loginTypeBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_one_key_login_btn");

                if (loginTypeBtn != null) {
                    loginTypeBtn.click();
                    Thread.sleep(5000);
                }

                WebElement mobileLogin = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_et");
                WebElement mobileInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_name_et");
                if (mobileInput == null) {
                    mobileInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_et");
                }
                if (mobileInput != null) {
                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                    String token = KuaimiUtil.kuaimiLogin();
                    String mobile = KuaimiUtil.getMobile(token, "2307");
                    mobileInput.sendKeys(mobile);
                    Thread.sleep(2000L);
                    WebElement nextBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/next_view");
                    if (nextBtn != null) {
                        nextBtn.click();
                        Thread.sleep(5000L);
                    }
                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                    WebElement pintu = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/title_tv");
                    if (pintu != null && pintu.getText().equals("拖动滑块")) {
                        WebElement leftBtn1 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                        leftBtn1.click();
                        return;
                    }
                    WebElement loginTitle = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_title_tv");
                    WebElement forgetBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/forget_psd_btn");
                    WebElement captcha = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_et");
                    WebElement captchaCode = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
                    if (loginTitle != null && loginTitle.getText().equals("输入密码")) {
                        forgetBtn.click();
                        Thread.sleep(2000L);
                        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                        WebElement sendMsgBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/verify_tv");
                        sendMsgBtn.click();
                        Thread.sleep(5000L);
                        int i = 0;
                        String msg = null;
                        while (i < 20) {
                            try {
                                msg = KuaimiUtil.getMessage(token, "2307", mobile);
                            } catch (Exception e) {
                                System.out.println("等待" + mobile + "短信验证码");
                            }
                            if (msg != null) {
                                WebElement captchrInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/verify_et");
                                captchrInput.sendKeys(msg);
                                Thread.sleep(2000);
                                WebElement confirmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                confirmBtn.click();
                                Thread.sleep(2000);
                                WebElement resetSelect = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/avatar_layout_one");
                                if (resetSelect != null) {
                                    resetSelect.click();
                                    Thread.sleep(2000);
                                }
                                WebElement newPwdInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_psd_et");
                                newPwdInput.sendKeys("a123456");
                                Thread.sleep(2000);
                                WebElement confirmBtn2 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                confirmBtn2.click();
                                Thread.sleep(3000);
                                WebElement continueBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                                if (continueBtn != null) {
                                    continueBtn.click();
                                }
                                for (int j = 0; j < 3; j++) {
                                    Thread.sleep(3000);
                                    WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                                    if (leftBtn != null) {
                                        leftBtn.click();
                                    }
                                }

                                Thread.sleep(3000);
                                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                WebElement headImg = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                                if (headImg != null) {
                                    headImg.click();
                                    Thread.sleep(3000);
                                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                    tapPoint(androidDriver, 650, 400);
                                    Thread.sleep(3000);
                                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
//                                    WebElement qrCode = getElementByType(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                                    WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                    System.out.println(kwid.getText());
                                } else {
                                    Thread.sleep(3000);
                                    tapPoint(androidDriver, 650, 1230);
                                    Thread.sleep(3000);
                                    tapPoint(androidDriver, 650, 1230);
                                    Thread.sleep(3000);
                                    tapPoint(androidDriver, 650, 400);
                                    Thread.sleep(3000);
//                                    WebElement qrCode = getElementByType(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                                    WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                    System.out.println(kwid.getText());
                                }

                                break;
                            }
                            i++;
                            Thread.sleep(5000);
                        }
                        if (i == 20) {
                            KuaimiUtil.addBlackList(token, "2307", mobile);
                        }
                    } else if (captcha != null) {
                        int i = 0;
                        String msg = null;
                        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                        while (i < 20) {

                            try {
                                msg = KuaimiUtil.getMessage(token, "2307", mobile);
                            } catch (Exception e) {
                                System.out.println("等待" + mobile + "短信验证码");
                            }
                            if (msg != null) {
                                Thread.sleep(2000);
                                WebElement captchaInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_et");
                                captchaInput.sendKeys(msg);
                                Thread.sleep(10000);
                                WebElement captchaConfirm = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_finish");

                                captchaConfirm.click();
                                System.out.println(msg);
                                Thread.sleep(5000);
                                WebElement icon = getElementByType(androidDriver, FIND_ELEMENT_TYPE_XPATH, "//android.widget.ImageView[@content-desc=\"头像\"]");
                                if (icon != null) {
                                    icon.click();
                                }
                                Thread.sleep(3000);
                                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                WebElement continueBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                                if (continueBtn != null) {
                                    continueBtn.click();
                                }
                                for (int j = 0; j < 3; j++) {
                                    Thread.sleep(3000);
                                    WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                                    if (leftBtn != null) {
                                        leftBtn.click();
                                    }
                                }
                                Thread.sleep(3000);
                                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                WebElement headImg = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                                if (headImg != null) {
                                    headImg.click();
                                    Thread.sleep(3000);
                                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                    tapPoint(androidDriver, 650, 400);
                                    Thread.sleep(3000);
                                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
//                                    WebElement qrCode = getElementByType(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                                    WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                    System.out.println(kwid.getText());
                                } else {
                                    Thread.sleep(3000);
                                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                    tapPoint(androidDriver, 650, 1230);
                                    Thread.sleep(3000);
                                    tapPoint(androidDriver, 650, 1230);
                                    Thread.sleep(3000);
                                    tapPoint(androidDriver, 650, 400);
                                    Thread.sleep(3000);
//                                    WebElement qrCode = getElementByType(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                                    WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                    System.out.println(kwid.getText());
                                }
                                //封禁
                                break;
                            }
                            i++;
                            Thread.sleep(5000);
                        }
                        if (i == 20) {
                            KuaimiUtil.addBlackList(token, "2307", mobile);
                        }
                    } else if (captchaCode != null) {
                        WebElement fetchCodeTv = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "fetch_code_tv");
                        fetchCodeTv.click();
                        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                        String msg = null;
                        int i = 0;
                        while (i < 20) {
                            try {
                                msg = KuaimiUtil.getMessage(token, "2307", mobile);
                            } catch (Exception e) {
                                System.out.println("等待" + mobile + "短信验证码");
                            }
                            if (msg != null) {
                                WebElement captchrInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
                                captchrInput.sendKeys(msg);
                                Thread.sleep(5000);
                                WebElement confirmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                if (confirmBtn != null) {
                                    confirmBtn.click();
                                }

                                Thread.sleep(5000);
                                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                WebElement newPwdInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_psd_et");
                                if (newPwdInput != null) {
                                    newPwdInput.sendKeys("a123456");
                                    Thread.sleep(5000);
                                    WebElement confirmBtn2 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                    confirmBtn2.click();
                                    Thread.sleep(3000);
                                }

                                WebElement continueBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                                if (continueBtn != null) {
                                    continueBtn.click();
                                }
                                Thread.sleep(3000);
                                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                for (int j = 0; i < 3; j++) {
                                    Thread.sleep(3000);
                                    WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                                    if (leftBtn != null) {
                                        leftBtn.click();
                                    }
                                }

                                WebElement headImg = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                                if (headImg != null) {
                                    headImg.click();
                                    Thread.sleep(3000);
                                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                    WebElement qrCode = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/qr_code_image");
                                    qrCode.click();
                                    WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                    System.out.println(kwid.getText());
                                } else {
                                    Thread.sleep(3000);
                                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                                    tapPoint(androidDriver, 650, 1230);
                                    Thread.sleep(3000);
                                    tapPoint(androidDriver, 650, 1230);
                                    Thread.sleep(3000);
                                    tapPoint(androidDriver, 650, 400);
                                    Thread.sleep(3000);
//                                    WebElement qrCode = getElementByType(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                                    WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                    System.out.println(kwid.getText());
                                }
                                //封禁判断
                                break;
                            }
                            i++;
                            Thread.sleep(5000);
                        }
                        if (i == 20) {
                            KuaimiUtil.addBlackList(token, "2307", mobile);
                        }

                    }
                }
                if (loginTypeBtn != null) {
                    loginTypeBtn.click();
                    Thread.sleep(5000);
                    System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                    mobileInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_name_et");
//                    if (mobileInput == null){
//                        mobileInput = getElementByType(androidDriver,"com.smile.gifmaker:id/phone_et");
//                    }
                    WebElement oneKeyLoginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_one_key_login_btn");
                    WebElement captchaCode = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
                    if (mobileInput != null) {

                    } else {
                        if (oneKeyLoginBtn != null || captchaCode != null) {
                            if (oneKeyLoginBtn != null) {
                                oneKeyLoginBtn.click();
                            }

                            Thread.sleep(5000);
                            WebElement phoneEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_et");
                            if (phoneEt != null) {
                                String token = KuaimiUtil.kuaimiLogin();
                                String mobile = KuaimiUtil.getMobile(token, "2307");
                                phoneEt.sendKeys(mobile);
                                Thread.sleep(5000L);
                                WebElement fetchCodeTv = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "fetch_code_tv");
                                fetchCodeTv.click();
                                String msg = null;
                                int i = 0;
                                while (i < 20) {
                                    try {
                                        msg = KuaimiUtil.getMessage(token, "2307", mobile);
                                    } catch (Exception e) {
                                        System.out.println("等待" + mobile + "短信验证码");
                                    }
                                    if (msg != null) {
                                        WebElement captchrInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
                                        captchrInput.sendKeys(msg);
                                        Thread.sleep(5000);
                                        WebElement confirmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                        confirmBtn.click();
                                        Thread.sleep(5000);
                                        WebElement newPwdInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_psd_et");
                                        if (newPwdInput != null) {
                                            newPwdInput.sendKeys("a123456");
                                            Thread.sleep(5000);
                                            WebElement confirmBtn2 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                            confirmBtn2.click();
                                            Thread.sleep(3000);
                                        }

                                        WebElement continueBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                                        if (continueBtn != null) {
                                            continueBtn.click();
                                        }
                                        for (int j = 0; i < 3; j++) {
                                            Thread.sleep(3000);
                                            WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                                            if (leftBtn != null) {
                                                leftBtn.click();
                                            }

                                        }

                                        WebElement headImg = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                                        if (headImg != null) {
                                            headImg.click();
                                            Thread.sleep(3000);
                                            WebElement qrCode = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/qr_code_image");
                                            qrCode.click();
                                            WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                            System.out.println(kwid.getText());
                                        } else {
                                            Thread.sleep(3000);
                                            tapPoint(androidDriver, 650, 1230);
                                            Thread.sleep(3000);
                                            tapPoint(androidDriver, 650, 1230);
                                            Thread.sleep(3000);
                                            tapPoint(androidDriver, 650, 400);
                                            Thread.sleep(3000);
//                                    WebElement qrCode = getElementById(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                                            WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                            System.out.println(kwid.getText());
                                        }
                                        //封禁判断
                                        break;
                                    }
                                    i++;
                                    Thread.sleep(5000);
                                }
                                if (i == 20) {
                                    KuaimiUtil.addBlackList(token, "2307", mobile);
                                }
                            }
                        }
                    }
                }
            }

            WebElement fullScreenLoginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_text");
            if (fullScreenLoginBtn != null) {
                fullScreenLoginBtn.click();
                Thread.sleep(5000);
                System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
                WebElement oneKeyLoginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_one_key_login_btn");
                if (oneKeyLoginBtn != null) {
                    oneKeyLoginBtn.click();
                }
                WebElement phoneLogin = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_login_view");
                if (phoneLogin != null) {
                    phoneLogin.click();
                }
                Thread.sleep(5000);
                Thread.sleep(5000);
                WebElement mobileInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_name_et");
//                    if (mobileInput == null){
//                        mobileInput = getElementByType(androidDriver,"com.smile.gifmaker:id/phone_et");
//                    }
                oneKeyLoginBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_one_key_login_btn");
                WebElement captchaCode = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
                if (mobileInput != null) {

                } else {
                    if (oneKeyLoginBtn != null || captchaCode != null) {
                        if (oneKeyLoginBtn != null) {
                            oneKeyLoginBtn.click();
                        }

                        Thread.sleep(5000);
                        WebElement phoneEt = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/phone_et");
                        if (phoneEt != null) {
                            String token = KuaimiUtil.kuaimiLogin();
                            String mobile = KuaimiUtil.getMobile(token, "2307");
                            phoneEt.sendKeys(mobile);
                            Thread.sleep(5000L);
                            WebElement fetchCodeTv = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "fetch_code_tv");
                            fetchCodeTv.click();
                            String msg = null;
                            int i = 0;
                            while (i < 20) {
                                try {
                                    msg = KuaimiUtil.getMessage(token, "2307", mobile);
                                } catch (Exception e) {
                                    System.out.println("等待" + mobile + "短信验证码");
                                }
                                if (msg != null) {
                                    WebElement captchrInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/captcha_code_et");
                                    captchrInput.sendKeys(msg);
                                    Thread.sleep(5000);
                                    WebElement confirmBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                    confirmBtn.click();
                                    Thread.sleep(5000);
                                    WebElement newPwdInput = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/login_psd_et");
                                    if (newPwdInput != null) {
                                        newPwdInput.sendKeys("a123456");
                                        Thread.sleep(5000);
                                        WebElement confirmBtn2 = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/confirm_btn");
                                        confirmBtn2.click();
                                        Thread.sleep(3000);
                                    }

                                    WebElement continueBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/positive");
                                    if (continueBtn != null) {
                                        continueBtn.click();
                                    }
                                    for (int j = 0; i < 3; j++) {
                                        Thread.sleep(3000);
                                        WebElement leftBtn = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/left_btn");
                                        if (leftBtn != null) {
                                            leftBtn.click();
                                        }

                                    }

                                    WebElement headImg = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/tab_avatar");
                                    if (headImg != null) {
                                        headImg.click();
                                        Thread.sleep(3000);
                                        WebElement qrCode = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/qr_code_image");
                                        qrCode.click();
                                        WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                        System.out.println(kwid.getText());
                                    } else {
                                        Thread.sleep(3000);
                                        tapPoint(androidDriver, 650, 1230);
                                        Thread.sleep(3000);
                                        tapPoint(androidDriver, 650, 1230);
                                        Thread.sleep(3000);
                                        tapPoint(androidDriver, 650, 400);
                                        Thread.sleep(3000);
//                                    WebElement qrCode = getElementByType(androidDriver,"com.smile.gifmaker:id/qr_code_image");
//                                    qrCode.click();
                                        WebElement kwid = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/kwai_id");
                                        System.out.println(kwid.getText());
                                    }
                                    //封禁判断
                                    break;
                                }
                                i++;
                                Thread.sleep(5000);
                            }
                            if (i == 20) {
                                KuaimiUtil.addBlackList(token, "2307", mobile);
                            }
                        }
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            androidDriver.quit();
        }

    }

    public void permissionAllow(AndroidDriver androidDriver) {
        WebElement element = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.android.packageinstaller:id/permission_allow_button");
        if (element != null) {
            element.click();
        }
    }

    public void closeBtnClick(AndroidDriver androidDriver) {
        WebElement element = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/close_btn");
        if (element != null) {
            element.click();
        }
    }

    public void backToMain(AndroidDriver androidDriver) {
        WebElement element = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/back_btn");
        if (null != element) {
            element.click();
        }
    }

    public Boolean checkAdvertiser(AndroidDriver androidDriver, String advertiserName) {
        WebElement label = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/label");
        String text = label.getText();
        if (null != label && null != text && text.startsWith(advertiserName)) {
            //表示广告筛选成功
            return true;
        } else {
            backToMain(androidDriver);
            return false;
        }
    }

    public WebElement getElementByType(AndroidDriver androidDriver, String type, String typeInfo) {
        WebElement element = null;
        if (type.equals(FIND_ELEMENT_TYPE_ID)) {
            element = androidDriver.findElementById(typeInfo);
        }
        if (type.equals(FIND_ELEMENT_TYPE_CLASS)) {
            element = androidDriver.findElementByClassName(typeInfo);
        }
        if (type.equals(FIND_ELEMENT_TYPE_XPATH)) {
            element = androidDriver.findElementByXPath(typeInfo);
        }
        return element;
    }

    public void runTaskV2(AndroidDriver androidDriver) throws Exception {
        System.out.println(androidDriver.getCurrentPackage() + ":" + androidDriver.currentActivity());
        //1:先打开快手
        Thread.sleep(3000L);
        WebElement checkElement = getElementByType(androidDriver, FIND_ELEMENT_TYPE_CLASS, "android.widget.CheckedTextView");
        if (null != checkElement) {
            checkElement.click();
        }
        //2:查询《发现》按钮，然后点击
        Thread.sleep(3000L);
        WebElement findElement = getElementByType(androidDriver, FIND_ELEMENT_TYPE_XPATH, "//android.view.View[@content-desc=\"发现\"]");
        if (null != findElement) {
            findElement.click();
        }
        //外层轮询
        boolean loopout = true;
        while (loopout) {
            //3：查询当前页面subjectList
            List<WebElement> list = getElementsByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/subject");
            //4：轮询subjectlist 查询广告
            for (WebElement element : list) {
                Thread.sleep(1000L);
                String subjectText = element.getText();
                //6：发现广告 点击广告
                if (null != subjectText && subjectText.equals("广告")) {
                    Point point = element.getLocation();
                    tapPoint(androidDriver, point.getX() - 10, point.getY() - 10);
                    log.info("x:{};y:{}", point.getX() - 10, point.getY() - 10);
                    Thread.sleep(1000L);
                    //7：上划页面 查询广告主名称
                    swipeToUp(androidDriver);
                    Thread.sleep(1000L);
                    WebElement label = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/label");
                    if (null != label) {
                        String text = label.getText();
                        if (null != text && text.startsWith("土巴兔")) {
                            //表示广告筛选成功
                            WebElement installElement = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/ad_simplified_style_enhanced_ad_install_text");
                            if (null != installElement) {
                                installElement.click();
                                return;
                            }
                            System.out.println("install元素查询失败");
                            WebElement downloadElement = getElementByType(androidDriver, FIND_ELEMENT_TYPE_ID, "com.smile.gifmaker:id/ad_download_text");
                            if (null != downloadElement) {
                                downloadElement.click();
                                return;
                            }
                            System.out.println("download元素查询失败");
                        }
                    }
                    backToMain(androidDriver);
                    Thread.sleep(1000L);
                }
            }
            swipeToUp(androidDriver);
        }
    }

    public void runTask(AndroidDriver androidDriver, AppiumTaskItem appiumTaskItem, WebElement loopElement) throws Exception {
        if (appiumTaskItem != null) {
            System.out.println(new Gson().toJson(appiumTaskItem));
            if (appiumTaskItem.getWaitTime() != null && appiumTaskItem.getWaitTime() > 0) {
                Thread.sleep(appiumTaskItem.getWaitTime());
            }
            if (appiumTaskItem.getLoopType() != null && appiumTaskItem.getLoopType().equals("noloop")) {
                //非循环类型任务
                if (appiumTaskItem.getFindType() != null) {
                    WebElement element = null;
                    if (appiumTaskItem.getFindType().equals("loop")) {
                        element = loopElement;
                    } else {
                        element = getElementByType(androidDriver, appiumTaskItem.getFindType(), appiumTaskItem.getFindKey());
                    }
                    if (element != null) {
                        if (appiumTaskItem.getTextEqualType() != null) {
                            if (appiumTaskItem.getTextEqualType().equals("eq")) {
                                if (!element.getText().equals(appiumTaskItem.getTextEqualKey())) {
                                    return;
                                }
                            } else if (appiumTaskItem.getTextEqualType().equals("neq")) {
                                if (element.getText() == null || element.getText().equals(appiumTaskItem.getTextEqualKey())) {
                                    return;
                                }
                            } else if (appiumTaskItem.getTextEqualType().equals("start")) {
                                boolean check = checkAdvertiser(androidDriver, appiumTaskItem.getTextEqualKey());
                                if (!check) {
                                    return;
                                }
                            }
                        }
                        if (appiumTaskItem.getClickType() != null) {
                            if (appiumTaskItem.getClickType().equals("element")) {
                                element.click();
                            } else if (appiumTaskItem.getClickType().equals("point")) {
                                Point point = element.getLocation();
                                tapPoint(androidDriver, point.getX() + appiumTaskItem.getOffsiteX(), point.getY() + appiumTaskItem.getOffsiteY());
                            }
                        }
                        List<AppiumTaskItem> subTask = appiumTaskItem.getSubList();
                        if (subTask != null && subTask.size() > 0) {
                            for (AppiumTaskItem task : subTask) {
                                runTask(androidDriver, task, element);
                            }
                        }
                    } else {
                        //必须执行
                        if (appiumTaskItem.getIsMust() != null && appiumTaskItem.getIsMust() == 1) {
                            if (appiumTaskItem.getLoopRate() != null && appiumTaskItem.getLoopRate() > 0) {
                                Thread.sleep(appiumTaskItem.getLoopRate());
                            }
                            runTask(androidDriver, appiumTaskItem, element);
                            return;
                        }
                        //非必须执行情况下
                        if (appiumTaskItem.getClickType() != null && appiumTaskItem.getClickType().equals("point")) {
                            tapPoint(androidDriver, appiumTaskItem.getOffsiteX(), appiumTaskItem.getOffsiteY());
                        }
                    }
                }
                if (appiumTaskItem.getSwapType() != null) {
                    swipeByType(androidDriver, appiumTaskItem.getSwapType());
                }
            } else if (appiumTaskItem.getLoopType() != null && appiumTaskItem.getLoopType().equals("loop")) {
                while (isLoop) {
                    System.out.println("loop:" + isLoop);
                    if (appiumTaskItem.getFindType() != null) {
                        List<WebElement> list = getElementsByType(androidDriver, appiumTaskItem.getFindType(), appiumTaskItem.getFindKey());
                        if (list != null && list.size() > 0) {
                            for (WebElement element : list) {
                                if (!isLoop) {
                                    break;
                                }
                                if (appiumTaskItem.getLoopRate() != null && appiumTaskItem.getLoopRate() > 0) {
                                    Thread.sleep(appiumTaskItem.getLoopRate());
                                }
                                List<AppiumTaskItem> subTask = appiumTaskItem.getSubList();
                                if (subTask != null && subTask.size() > 0) {
                                    for (AppiumTaskItem task : subTask) {
                                        runTask(androidDriver, task, element);
                                    }
                                }
                            }
                        }
                    }
                    if (appiumTaskItem.getSwapType() != null) {
                        swipeByType(androidDriver, appiumTaskItem.getSwapType());
                    }
                }

            }
            if (appiumTaskItem.getIsClose() != null && appiumTaskItem.getIsClose() == 1) {
                this.isLoop = false;
            }
        }
    }

    private void swipeByType(AndroidDriver androidDriver, String type) {
        if (type.equals(APP_SWIPE_TYPE_UP)) {
            this.swipeToUp(androidDriver);
        } else if (type.equals(APP_SWIPE_TYPE_DOWN)) {
            this.swipeToDown(androidDriver);
        } else if (type.equals(APP_SWIPE_TYPE_LEFT)) {
            this.swipeToLeft(androidDriver);
        } else if (type.equals(APP_SWIPE_TYPE_RIGHT)) {
            this.swipeToRight(androidDriver);
        }
    }

    private List<WebElement> getElementsByType(AndroidDriver androidDriver, String findType, String findKey) {
        List<WebElement> elements = null;
        if (findType.equals(FIND_ELEMENT_TYPE_ID)) {
            elements = androidDriver.findElementsById(findKey);
        } else if (findType.equals(FIND_ELEMENT_TYPE_CLASS)) {
            elements = androidDriver.findElementsByClassName(findKey);
        } else if (findKey.equals(FIND_ELEMENT_TYPE_XPATH)) {
            elements = androidDriver.findElementsByXPath(findKey);
        }
        return elements;
    }
}
